==> gs2-java-cdk-1.0.42-sources.jar: io/gs2/cdk/inbox/model/options/GlobalMessageOptions.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.inbox.model.options;
import io.gs2.cdk.core.model.AcquireAction;
import io.gs2.cdk.inbox.model.TimeSpan;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.stream.Collectors;

public class GlobalMessageOptions {
    public List<AcquireAction> readAcquireActions;
    public TimeSpan expiresTimeSpan;
    public Long expiresAt;
    
    public GlobalMessageOptions withReadAcquireActions(
        List<AcquireAction> readAcquireActions
    ) {
        this.readAcquireActions = readAcquireActions;
        return this;
    }
    
    public GlobalMessageOptions withExpiresTimeSpan(
        TimeSpan expiresTimeSpan
    ) {
        this.expiresTimeSpan = expiresTimeSpan;
        return this;
    }
    
    public GlobalMessageOptions withExpiresAt(
        Long expiresAt
    ) {
        this.expiresAt = expiresAt;
        return this;
    }
}

==> gs2-java-cdk-1.0.58-sources.jar: io/gs2/cdk/inbox/model/options/GlobalMessageOptions.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.inbox.model.options;
import io.gs2.cdk.core.model.AcquireAction;
import io.gs2.cdk.inbox.model.TimeSpan;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.stream.Collectors;

public class GlobalMessageOptions {
    public List<AcquireAction> readAcquireActions;
    public TimeSpan expiresTimeSpan;
    public Long expiresAt;
    public String messageReceptionPeriodEventId;
    
    public GlobalMessageOptions withReadAcquireActions(
        List<AcquireAction> readAcquireActions
    ) {
        this.readAcquireActions = readAcquireActions;
        return this;
    }
    
    public GlobalMessageOptions withExpiresTimeSpan(
        TimeSpan expiresTimeSpan
    ) {
        this.expiresTimeSpan = expiresTimeSpan;
        return this;
    }
    
    public GlobalMessageOptions withExpiresAt(
        Long expiresAt
    ) {
        this.expiresAt = expiresAt;
        return this;
    }
    
    public GlobalMessageOptions withMessageReceptionPeriodEventId(
        String messageReceptionPeriodEventId
    ) {
        this.messageReceptionPeriodEventId = messageReceptionPeriodEventId;
        return this;
    }
}
